<!--
 Description: 设备特殊字符管理页面 List
 Author: 作者 liuyh
 Date:   2025-01-15
-->
<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="设备编号">
              <a-input placeholder="请输入设备编号" v-model="queryParam.deviceNo"></a-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="特殊字符">
              <a-input placeholder="请输入特殊字符" v-model="queryParam.characters"></a-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
            <a-col :md="4" :sm="4">
              <a-form-item label="车间名称">
                <!--<a-input placeholder="请输入车间名称" v-model="queryParam.productionName"></a-input>-->
                <a-tree-select v-model="queryParam.departId" :treeData="workshopTreeData" placeholder="请选择车间"
                               :treeDefaultExpandedKeys="treeDefaultExpandedKeys"></a-tree-select>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="数控系统">
                <a-input placeholder="请输入数控系统" v-model="queryParam.controlSystem"></a-input>
              </a-form-item>
            </a-col>
            <a-col :xl="10" :lg="11" :md="12" :sm="24">
              <a-form-item label="操作时间">
                <j-date :show-time="true" date-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择开始时间" class="query-group-cust" v-model="queryParam.startTime"></j-date>
                <span class="query-group-split-cust"></span>
                <j-date :show-time="true" date-format="YYYY-MM-DD HH:mm:ss" placeholder="请选择结束时间" class="query-group-cust" v-model="queryParam.endTime"></j-date>
              </a-form-item>
            </a-col>
          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <a @click="handleToggleSearch" style="margin-left: 8px">{{ toggleSearchStatus ? '收起' : '展开' }}<a-icon :type="toggleSearchStatus ? 'up' : 'down'" /></a>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
    </div>

    <!-- table区域-begin -->
    <div>

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>
          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多
              <a-icon type="down" />
            </a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>


    <NcDeviceCharactersModal ref="modalForm" @ok="modalFormOk"></NcDeviceCharactersModal>

  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag.vue'
import NcDeviceCharactersModal from './modules/NcDeviceCharacters/NcDeviceCharactersModal__Style#Drawer.vue'
import { queryProductionTreeList } from '@api/api'

export default {
  name: 'NcDeviceCharactersList',
  mixins:[JeecgListMixin, mixinDevice],
  components: {
    JDictSelectTag,
    NcDeviceCharactersModal
  },
  data () {
    return {
      description: '设备特殊字符管理页面',
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: '',
          key:'rowIndex',
          width:200,
          align:"center",
          customRender:function (t,r,index) {
            return parseInt(index)+1;
          }
        },
        {
          title: '设备编号',
          align: "center",
          dataIndex: 'deviceNo',
          width: 200,
        },
        {
          title: '所属车间',
          align: "center",
          dataIndex: 'departId_dictText',
          width: 220,
        },
        {
          title: '数控系统',
          align: "center",
          dataIndex: 'controlSystem',
          width: 250,
        },
        {
          title: '特殊字符',
          align: "center",
          dataIndex: 'characters',
          width:250
        },
        {
          title: '操作时间',
          align: "center",
          dataIndex: 'createTime',
          width:300
        },
        {
          title: '操作',
          dataIndex: 'action',
          scopedSlots: { customRender: 'action' },
          align: 'center',
          width: 200,
          fixed: 'right'
        }
      ],
      url: {
        list: "/nc/device/characters/find/page",
        delete: "/nc/device/characters/delete",
        deleteBatch: "/mdc/mdcDriveTypeParamConfig/deleteBatch",
        exportXlsUrl: "/mdc/mdcDriveTypeParamConfig/exportXls",
        importExcelUrl: "mdc/mdcDriveTypeParamConfig/importExcel",
      },
      dictOptions:{},
      workshopTreeData: [],
      treeDefaultExpandedKeys: []
    }
  },
  created() {
    this.getWorkshopListByApi()
  },
  computed: {
    importExcelUrl: function(){
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    },
  },
  methods: {
    initDictConfig(){
    },
    /**
     * 调用接口获取查询区域车间树列表
     */
    getWorkshopListByApi() {
      queryProductionTreeList().then(res => {
        if (res.success) {
          this.workshopTreeData = res.result
          this.treeDefaultExpandedKeys = [...res.result].map(item => item.key)
        }
      })
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>